@@ -19,5 +19,13 @@ class OneTimePasswordError(AppknoxError):
     pass
 
 
-class ReportError(AppknoxError):
+# class ReportError(AppknoxError):
+#     pass
+
+
+class OrganizationError(AppknoxError):
+    pass
+
+
+class UploadError(AppknoxError):
     pass
